@@ -3,12 +3,26 @@ import logging
 import pandas as pd
 from typing import List, Dict
 
-from auto_deep_learning.exceptions.functions import (
+from auto_deep_learning.exceptions.utils.functions import (
     ImbalancedClassError, 
-    IncorrectFolderStructure
+    IncorrectFolderStructure,
+    InvalidFileType
 )
 
 
+def check_numerical_value(
+    category_type: str
+):  
+    """Check if inside a string we have a numerical value.
+    This is becasue in the category_type provided to our model object, must only have characters.
+
+    Args:
+        category_type (str): the category type of the dataset
+    """
+
+    return any(char.isdigit() for char in category_type)
+
+
 def create_df_image_folder(
     columns: List[str], dtypes: Dict[str, str]
 ) -> pd.DataFrame:
@@ -47,7 +61,10 @@ def image_folder_convertion(
         'image_path': 'object',
         'class': 'category',
         'split_type': 'category'
-    }
+    },
+    save: bool = False,
+    save_path: str = 'data.csv'
+
 ):
     """
     Function to make the conversion from the image folder structure to a dataframe that is wanted.
@@ -63,12 +80,17 @@ def image_folder_convertion(
     dtypes : dict
         Dictionary for the column name : column dtype for the dataframe
     
+    save : bool
+        If we want to save the dataframe that we get
+    
     Returns
     -------
     df : pd.DataFrame
         The DataFrame that will be used for organizing the Image Folder information
     """
 
+    # TODO: Assess parent_folder str has not trailing /
+
     # Get the df we will use as the base one 
     df = create_df_image_folder(
         columns=columns,
@@ -101,7 +123,11 @@ def image_folder_convertion(
             # List the images we have inside that folder
             images_child_class_path: List[str] = os.listdir(images_path) 
 
-            # TODO: Asses they are files and of .jpg/png
+            for idx, file in enumerate(images_child_class_path):
+                if not file.endswith('.jpg') or file.endswith('.png'):
+                    raise InvalidFileType(file=file)
+
+                images_child_class_path[idx] = images_path + '/' + file
 
             class_list: List[str] = [child_class] * len(images_child_class_path)
             dtype_list: List[str] = [split_folder] * len(images_child_class_path)
@@ -127,7 +153,6 @@ def image_folder_convertion(
     
     # Checks once the pandas dataframe created, classes in train = test
     unique_per_class = df.groupby('split_type')['class'].unique()
-    print(unique_per_class)
 
     unique_per_class_test = list(set(unique_per_class[0]))
     unique_per_class_train = list(set(unique_per_class[1]))
@@ -139,7 +164,7 @@ def image_folder_convertion(
         len(unique_per_class_train),
         len(unique_per_class_valid)
     )):
-        print(idx, unique_per_class_test, unique_per_class_train, unique_per_class_valid)
+
         try:
             if not unique_per_class_test[idx] == unique_per_class_train[idx] == unique_per_class_valid[idx]:
                 raise ImbalancedClassError()
@@ -147,5 +172,11 @@ def image_folder_convertion(
         except IndexError:
             raise ImbalancedClassError()
 
-    
-    return df
\ No newline at end of file
+    if save:
+        df.to_csv(save_path, index=False, header=True)
+        
+    return df
+
+
+# TODO: tensor_dict = torch.load('model.dat', map_location='cpu') # OrderedDict
+# TODO: In Model, not only save hp but also the whole model if asked -> save on cpu
\ No newline at end of file
